@@ -17,7 +17,7 @@ static void BM_AlignAudioSeconds(benchmark::State& state) {
     }
     std::vector<Node> nodes;
     for (int i=0; i < num_nodes; i++) {
-      nodes.push_back(Node{.edges={Edge{.target=i+1, .class_id=rand() % num_classes}}});
+      nodes.push_back(Node{.edges={Edge{.class_id=rand() % num_classes, .target=i+1}}});
     }
     nodes.push_back(Node{});
 
